<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BreakOut</name>
    <message>
        <source>Choose line, arc, circle or ellipse to auto trim</source>
        <translation type="vanished">オートトリムのための線分、弧、円または楕円を選択してください</translation>
    </message>
    <message>
        <location filename="../BreakOut.js" line="+58"/>
        <source>Choose line, arc, circle, ellipse, spline or polyline segment</source>
        <translation>線分、弧、円、楕円、スプラインまたはポリラインの断片を選択して下さい</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline segment</source>
        <translation type="vanished">線分,弧,円,楕円またはスプラインを選択してください</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose line, arc, circle or ellipse segment</source>
        <translation>線分、弧、円または楕円の切片を選択してください</translation>
    </message>
    <message>
        <location filename="../BreakOut.ui" line="+17"/>
        <source>Remove Segment</source>
        <translation>セグメントを削除</translation>
    </message>
    <message>
        <location filename="../BreakOutInit.js" line="+2"/>
        <source>&amp;Break out Segment</source>
        <translation>&amp;B 切片除去</translation>
    </message>
</context>
</TS>
